window.Gleam.initSearch([{"doc":"javascript_dom_parser","title":"javascript_dom_parser","content":"# javascript_dom_parser\n\nBindings to the JavaScript `DOMParser` API.\n\n[![Package Version](https://img.shields.io/hexpm/v/javascript_dom_parser)](https://hex.pm/packages/javascript_dom_parser)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/javascript_dom_parser/)\n\n```sh\ngleam add javascript_dom_parser\n```\n```gleam\nimport javascript_dom_parser\n\npub fn main() {\n  let html = &quot;\n&lt;!doctype html&gt;\n&lt;html lang=en&gt;\n&lt;head&gt;\n  &lt;title&gt;Hi!&lt;/title&gt;\n&lt;/head&gt;\n&lt;body&gt;\n  &lt;p style=&#39;color: #ffaff3&#39;&gt;How are you?&lt;/p&gt;\n  &lt;!-- Wooo coding! --&gt;\n&lt;/body&gt;\n&lt;/html&gt;\n&quot;\n  javascript_dom_parser.parse_to_records(html)\n}\n```\nThis function will return a data structure like so:\n```gleam\nElement(&quot;HTML&quot;, [#(&quot;lang&quot;, &quot;en&quot;)], [\n  Element(&quot;HEAD&quot;, [], [\n    Text(&quot;\\n  &quot;),\n    Element(&quot;TITLE&quot;, [], [Text(&quot;Hi!&quot;)]),\n    Text(&quot;\\n&quot;),\n  ]),\n  Text(&quot;\\n&quot;),\n  Element(&quot;BODY&quot;, [], [\n    Text(&quot;\\n  &quot;),\n    Element(&quot;P&quot;, [#(&quot;style&quot;, &quot;color: #ffaff3&quot;)], [Text(&quot;How are you?&quot;)]),\n    Text(&quot;\\n  &quot;),\n    Comment(&quot; Wooo coding! &quot;),\n    Text(&quot;\\n\\n&quot;),\n  ]),\n])\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/javascript_dom_parser&gt;.\n","url":"index.html"},{"doc":"javascript_dom_parser","title":"Dom","content":"pub type Dom\n A reference to a node in a DOM tree, parsed from some HTML.\n\nSynonyms:\njavascript_dom_parser.Dom\njavascript_dom_parser Dom","url":"javascript_dom_parser.html#Dom"},{"doc":"javascript_dom_parser","title":"HtmlNode","content":"pub type HtmlNode {\n  Element(\n    tag: String,\n    attributes: List(#(String, String)),\n    children: List(HtmlNode),\n  )\n  Text(String)\n  Comment(String)\n}\n\nElement(\n  tag: String,\n  attributes: List(#(String, String)),\n  children: List(HtmlNode),\n)\n\ntag\n&lt;p&gt;The tag of the element, written in uppercase. For example:&lt;/p&gt;\n&lt;pre&gt;&lt;code class=&quot;language-html&quot;&gt;&amp;lt;div&amp;gt;Hello!&amp;lt;/div&amp;gt;\n&lt;/code&gt;&lt;/pre&gt;\n&lt;p&gt;Would have the tag &lt;code&gt;&quot;DIV&quot;&lt;/code&gt;.&lt;/p&gt;\n\nattributes\n&lt;p&gt;The attributes of the element. For example:&lt;/p&gt;\n&lt;pre&gt;&lt;code class=&quot;language-html&quot;&gt;&amp;lt;div class=&quot;greeting&quot;&amp;gt;Hello!&amp;lt;/div&amp;gt;\n&lt;/code&gt;&lt;/pre&gt;\n&lt;p&gt;Would have the attributes &lt;code&gt;[#(&quot;class&quot;, &quot;greeting&quot;)]&lt;/code&gt;.&lt;/p&gt;\n\nchildren\n&lt;p&gt;The children of the element.&lt;/p&gt;\n\nText(String)\n\n\nComment(String)\n\n\nSynonyms:\njavascript_dom_parser.HtmlNode\njavascript_dom_parser HtmlNode","url":"javascript_dom_parser.html#HtmlNode"},{"doc":"javascript_dom_parser","title":"dom_to_records","content":"pub fn dom_to_records(html: Dom) -&gt; HtmlNode\n Convert from JavaScript DOM to Gleam records representing the same\n document.\n\nSynonyms:\njavascript_dom_parser.dom_to_records\njavascript_dom_parser dom_to_records","url":"javascript_dom_parser.html#dom_to_records"},{"doc":"javascript_dom_parser","title":"dom_to_string","content":"pub fn dom_to_string(element: Dom) -&gt; String\n Convert DOM into HTML.\n\nSynonyms:\njavascript_dom_parser.dom_to_string\njavascript_dom_parser dom_to_string","url":"javascript_dom_parser.html#dom_to_string"},{"doc":"javascript_dom_parser","title":"parse_to_dom","content":"pub fn parse_to_dom(html: String) -&gt; Dom\n Parse HTML to the DOM using the JavaScript `DOMParser`. Any invalid HTML\n will be converted into a valid document with a similar structure rather\n than returning an error or crashing.\n \n For more information see JavaScript documentation for the `DOMParser`:\n &lt;https://developer.mozilla.org/en-US/docs/Web/API/DOMParser&gt;\n\nSynonyms:\njavascript_dom_parser.parse_to_dom\njavascript_dom_parser parse_to_dom","url":"javascript_dom_parser.html#parse_to_dom"},{"doc":"javascript_dom_parser","title":"parse_to_records","content":"pub fn parse_to_records(html: String) -&gt; HtmlNode\n Parse HTML to Gleam records using the JavaScript `DOMParser`. Any invalid\n HTML will be converted into a valid document with a similar structure\n rather than returning an error or crashing.\n \n For more information see JavaScript documentation for the `DOMParser`:\n &lt;https://developer.mozilla.org/en-US/docs/Web/API/DOMParser&gt;\n\nSynonyms:\njavascript_dom_parser.parse_to_records\njavascript_dom_parser parse_to_records","url":"javascript_dom_parser.html#parse_to_records"},{"doc":"javascript_dom_parser","title":"javascript_dom_parser","content":" Bindings to the JavaScript `DOMParser` API, to enable parsing of HTML in\n the browser with Gleam. And any other JavaScript runtimes that have\n `DOMParser`.\n","url":"javascript_dom_parser.html"},{"doc":"javascript_dom_parser/deno_polyfill","title":"install_polyfill","content":"pub fn install_polyfill() -&gt; Nil\n Install the `deno_dom` polyfill for the JavaScript `DOMParser`, mutating\n the global scope to add the `DOMParser` object. If running outside of\n browser you may want to run this at the start of your program.\n\n Note this will only work on Deno!\n\n For more information see the documentation:\n &lt;https://deno.land/x/deno_dom&gt;\nSynonyms:\njavascript_dom_parser/deno_polyfill.install_polyfill\njavascript_dom_parser/deno_polyfill install_polyfill","url":"javascript_dom_parser/deno_polyfill.html#install_polyfill"},{"doc":"javascript_dom_parser/deno_polyfill","title":"javascript_dom_parser/deno_polyfill","content":"","url":"javascript_dom_parser/deno_polyfill.html"}]);